package com.jmstudios.redmoon.preference;

import android.content.Context;
import android.content.res.TypedArray;
import android.preference.DialogPreference;
import android.util.AttributeSet;
import android.view.View;
import android.widget.TimePicker;
import android.util.Log;
import android.support.annotation.NonNull;
import android.os.Build.VERSION;
import android.text.format.DateFormat;

import com.jmstudios.redmoon.R;

public class TimePickerPreference extends DialogPreference {
    public static final String DEFAULT_VALUE = "00:00";

    private static final String TAG = "TimePickerPref";
    private static final boolean DEBUG = true;

    private TimePicker mTimePicker;
    private String mTime;

    public TimePickerPreference(Context context, AttributeSet attrs) {
        super(context, attrs);

        setPositiveButtonText(getContext().getResources().getString
                              (R.string.set_dialog));
        setNegativeButtonText(getContext().getResources().getString
                              (R.string.cancel_dialog));
    }

    @Override
    protected Object onGetDefaultValue(TypedArray a, int index) {
        return a.getString(index);
    }

    @Override
    protected void onSetInitialValue(boolean restorePersistedValue, Object defaultValue) {
        if (restorePersistedValue) {
            mTime = getPersistedString(DEFAULT_VALUE);
        } else {
            mTime = (String) defaultValue;
            persistString(mTime);
        }
    }

    @Override
    protected void onBindView(@NonNull View view) {
        super.onBindView(view);
    }

    @Override
    protected View onCreateDialogView() {
        mTimePicker = new TimePicker(getContext());
        mTimePicker.setIs24HourView(DateFormat.is24HourFormat(getContext()));
        return mTimePicker;
    }

    @Override
    protected void onBindDialogView(View v) {
        super.onBindDialogView(v);

        int hour = Integer.parseInt(mTime.split(":")[0]);
        int minute = Integer.parseInt(mTime.split(":")[1]);
        if (android.os.Build.VERSION.SDK_INT >= 23) {
            mTimePicker.setHour(hour);
            mTimePicker.setMinute(minute);
        } else {
            mTimePicker.setCurrentHour(hour);
            mTimePicker.setCurrentMinute(minute);
        }
    }

    @Override
    protected void onDialogClosed(boolean positiveResult) {
        super.onDialogClosed(positiveResult);

        if (positiveResult) {
            int hour = 0, minute = 0;
            if (android.os.Build.VERSION.SDK_INT >= 23) {
                hour = mTimePicker.getHour();
                minute = mTimePicker.getMinute();
            } else {
                hour = mTimePicker.getCurrentHour();
                minute = mTimePicker.getCurrentMinute();
            }

            mTime = (hour < 10 ? "0" : "") + Integer.toString(hour) + ":" +
                (minute < 10 ? "0" : "") + Integer.toString(minute);
            persistString(mTime);
        }
    }
}
